@@ -113,7 +113,7 @@ saveToCache <- function(cachePath = getOption("reproducible.cachePath"),
     suppressWarnings({
       out <- try(file.link(from = ftL, to = fts), silent = TRUE)
     })
-    if (is(out, "try-error") | !out)
+    if (is(out, "try-error") | !all((out %in% TRUE)))
       linkToCacheId <- NULL
     else {
       messageCache("  (A file with identical properties already exists in the Cache: ",basename(ftL),"; ",
@@ -129,7 +129,7 @@ saveToCache <- function(cachePath = getOption("reproducible.cachePath"),
   if (!useDBI()) {
     dtFile <- saveDBFileSingle(dt = dt, cachePath, cacheId)
     # dtFile <- CacheDBFileSingle(cachePath = cachePath, cacheId = cacheId)
-    # saveFileInCacheFolder(dt, dtFile, cachePath = cachePath, cacheId = cacheId)
+    # saveFilesInCacheFolder(dt, dtFile, cachePath = cachePath, cacheId = cacheId)
 
   } else {
     a <- retry(retries = 250, exponentialDecayBase = 1.01, quote(
@@ -137,12 +137,12 @@ saveToCache <- function(cachePath = getOption("reproducible.cachePath"),
   }
 
   if (is.null(linkToCacheId)) {
-    fs <- saveFileInCacheFolder(cachePath = cachePath, obj, fts, cacheId = cacheId)
+    fs <- saveFilesInCacheFolder(cachePath = cachePath, obj, fts, cacheId = cacheId)
   }
   if (isTRUE(getOption("reproducible.useMemoise"))) {
     if (is.null(.pkgEnv[[cachePath]]))
       .pkgEnv[[cachePath]] <- new.env(parent = emptyenv())
-    obj <- .dealWithClassOnRecovery(obj) # This takes time, but whether it happens now or later, same
+    obj <- .unwrap(obj) # This takes time, but whether it happens now or later, same
     obj2 <- makeMemoisable(obj)
     assign(cacheId, obj2, envir = .pkgEnv[[cachePath]])
   }
@@ -204,6 +204,9 @@ loadFromCache <- function(cachePath = getOption("reproducible.cachePath"),
     startLoadTime <- Sys.time()
   }
 
+  if (length(cacheId) > 1)
+    cacheId <- unique(cacheId)
+
   isMemoised <- NA
   if (isTRUE(getOption("reproducible.useMemoise"))) {
     if (is.null(.pkgEnv[[cachePath]]))
@@ -215,10 +218,10 @@ loadFromCache <- function(cachePath = getOption("reproducible.cachePath"),
     }
   }
 
-  fileFormat <- extractFromCache(fullCacheTableForObj, "fileFormat", ifNot = format)
+  # fileFormat <- extractFromCache(fullCacheTableForObj, "fileFormat", ifNot = format)
 
   if (!isTRUE(isMemoised)) {
-    f <- CacheStoredFile(cachePath, cacheId, fileFormat)
+    f <- CacheStoredFile(cachePath, cacheId, format)
     f <- unique(f) # It is OK if there is a vector of unique cacheIds e.g., loadFromCache(showCache(userTags = "hi")$cacheId)
 
     # First test if it is correct format
@@ -236,7 +239,7 @@ loadFromCache <- function(cachePath = getOption("reproducible.cachePath"),
                              cacheId = cacheId,
                              format = fileExt(sameCacheID),
                              verbose = verbose)
-        obj <- .dealWithClass(obj, cachePath = cachePath, drv = drv, conn = conn)
+        obj <- .wrap(obj, cachePath = cachePath, drv = drv, conn = conn)
         fs <- saveToCache(obj = obj, cachePath = cachePath, drv = drv, conn = conn,
                           cacheId = cacheId)
         rmFromCache(cachePath = cachePath, cacheId = cacheId, drv = drv, conn = conn,
@@ -245,8 +248,10 @@ loadFromCache <- function(cachePath = getOption("reproducible.cachePath"),
       }
     }
     # Need exclusive lock
-    obj <- loadFile(f, format = fileFormat, fullCacheTableForObj = fullCacheTableForObj)
-    obj <- .dealWithClassOnRecovery(obj, cachePath = cachePath,
+    obj <- loadFile(f, # format = fileFormat,
+                    fullCacheTableForObj = fullCacheTableForObj,
+                    cachePath = cachePath)
+    obj <- .unwrap(obj, cachePath = cachePath,
                                     cacheId = cacheId,
                                     drv = drv, conn = conn)
   }
@@ -397,7 +402,7 @@ dbConnectAll <- function(drv = getDrv(getOption("reproducible.drv", NULL)),
       dtFile <- CacheDBFileSingle(cachePath = cachePath, cacheId = cacheId)
       dt2 <- loadFile(dtFile)
       dt <- rbindlist(list(dt2, dt))
-      saveFileInCacheFolder(dt, dtFile, cachePath = cachePath, cacheId = cacheId)
+      saveFilesInCacheFolder(dt, dtFile, cachePath = cachePath, cacheId = cacheId)
     }
   }
 }
@@ -453,7 +458,7 @@ dbConnectAll <- function(drv = getDrv(getOption("reproducible.drv", NULL)),
       } else {
         dt2[tagKey == tk & cacheId == cacheId, tagValue := dt$tagValue]
       }
-      saveFileInCacheFolder(dt2, dtFile, cachePath = cachePath, cacheId = cacheId)
+      saveFilesInCacheFolder(dt2, dtFile, cachePath = cachePath, cacheId = cacheId)
     }
 
   }
@@ -469,22 +474,11 @@ dbConnectAll <- function(drv = getDrv(getOption("reproducible.drv", NULL)),
 }
 
 .cacheTableHashColName <- function() {
-  #if (useDBI()) {
     "cacheId"
-  #} else {
-  #  "artifact"
-  #}
 }
 
 .cacheTableTagColName <- function(option = NULL) {
-  out <- "tagValue"
-  # if (useDBI()) {
-  # } else {
-  #   if (isTRUE(option == "tag")) {
-  #     out <- "tag"
-  #   }
-  # }
-  out
+  "tagValue"
 }
 
 #' A collection of low level tools for Cache
@@ -581,16 +575,6 @@ CacheStoredFile <- function(cachePath = getOption("reproducible.cachePath"), cac
                             format = NULL, obj = NULL) {
 
   if (is.null(format)) format <- getOption("reproducible.cacheSaveFormat", "rds")
-  if (!is.null(obj)) {
-    theAttr <- attr(obj, "tags")
-    if (!is.null(theAttr)) {
-      if (any(theAttr == "saveRawFile:TRUE")) {
-        theGrep <- "fileFormat:"
-        format <- vapply(strsplit(split = ":", grep(theGrep, theAttr, value = TRUE)),
-                         function(fn) fn[2], FUN.VALUE = character(1))
-      }
-    }
-  }
   if (any(format %in% "check")) {
     format <- formatCheck(cachePath, cacheId, format)
   }
@@ -606,12 +590,14 @@ CacheStoredFile <- function(cachePath = getOption("reproducible.cachePath"), cac
       "rda"
   }
   filename <- paste(cacheId, csExtension, sep = ".")
-  if (length(filename) > 1) {
-    filename <- nextNumericName(filename)
+  if (length(cacheId) > 1) {
+    filename <- vapply(filename, nextNumericName, FUN.VALUE = character(1))
     for (i in seq(filename[-1]) + 1)
       filename[i] <- basename2(nextNumericName(filename[i - 1]))
   }
-  file.path(CacheStorageDir(cachePath), filename)
+
+  fns <- basename2(Filenames(obj, allowMultiple = TRUE))
+  file.path(CacheStorageDir(cachePath), c(filename, fns))
 }
 
 #' @rdname CacheHelpers
@@ -792,70 +778,55 @@ movedCache <- function(new, old, drv = getDrv(getOption("reproducible.drv", NULL
   return(invisible())
 }
 
-loadFile <- function(file, format = NULL, fullCacheTableForObj = NULL) {
+loadFile <- function(file, format = NULL, fullCacheTableForObj = NULL,
+                     cachePath = getOption("reproducible.cachePath")) {
   if (is.null(format))
     format <- fileExt(file)
 
-  tv <- fullCacheTableForObj$tagValue
-  tk <- fullCacheTableForObj$tagKey
-  loadFun <- tv[tk == "loadFun"]
-
-  if (length(loadFun) == 0) {
-    if (format %in% "qs") {
-      .requireNamespace("qs", stopOnFALSE = TRUE)
-      obj <- qs::qread(file = file, nthreads = getOption("reproducible.nThreads", 1))
-    } else {
-      obj <- readRDS(file = file)
-    }
+  if (format %in% "qs") {
+    .requireNamespace("qs", stopOnFALSE = TRUE)
+    obj <- qs::qread(file = file, nthreads = getOption("reproducible.nThreads", 1))
   } else {
-    whichFiles <- tv[tk == "whichFiles"]
-    origFilename <- tv[tk == "origFilename"]
-    origDirname <- tv[tk == "origDirname"]
-    origGetWd <- tv[tk == "origGetWd"]
-
-    relPath <- gsub(normPath(origGetWd), "", normPath(origDirname))
-    isAbs <- isAbsolutePath(relPath)
-    if (any(isAbs)) # means that it had a specific path, not just relative
-      newName <- file.path(normPath(origDirname), origFilename)
-    else
-      newName <- file.path(getwd(), relPath, origFilename)
-    whFiles <- newName[match(basename(whichFiles), origFilename)]
-    hardLinkOrCopy(file, newName, verbose = 0)
-    obj <- eval(parse(text = loadFun))(whFiles)
+    obj <- readRDS(file = file)
   }
+
+  obj
 }
 
-saveFileInCacheFolder <- function(obj, fts, cachePath, cacheId) {
+saveFilesInCacheFolder <- function(obj, fts, cachePath, cacheId) {
   if (missing(fts))
     fts <- CacheStoredFile(cachePath, cacheId = cacheId, obj = obj)
 
-  if (any(attr(obj, "tags") == "saveRawFile:TRUE")) {
-    # newFN <- paste0(tools::file_path_sans_ext(fts), ".", tools::file_ext(obj))
-    hardLinkOrCopy(obj, fts, verbose = -2)
-    fs <- sum(file.size(fts))
-
-  } else {
-    if (getOption("reproducible.cacheSaveFormat", "rds") == "qs") {
-      .requireNamespace("qs", stopOnFALSE = TRUE)
-      for (attempt in 1:2) {
-        fs <- qs::qsave(obj, file = fts, nthreads = getOption("reproducible.nThreads", 1),
-                        preset = getOption("reproducible.qsavePreset", "high"))
-        fs1 <- file.size(fts)
-        if (!identical(fs, fs1)) {
-          if (attempt == 1) {
-            warning("Attempted to save to Cache, but save seemed to fail; trying again")
-          } else {
-            stop("Saving to Cache did not work correctly; file appears corrupted. Please retry")
-          }
-        } else {
-          break
-        }
-      }
-    } else {
-      saveRDS(obj, file = fts)
-      fs <- file.size(fts)
-    }
+  fsOther <- numeric()
+  if (length(fts) > 1) {
+    ftsOther <- fts[-1]
+    fns <- Filenames(obj, allowMultiple = TRUE)
+    hardLinkOrCopy(fns, ftsOther, verbose = -2)
+    fsOther <- sum(file.size(ftsOther))
+    fts <- fts[1]
   }
+  if (getOption("reproducible.cacheSaveFormat", "rds") == "qs") {
+    .requireNamespace("qs", stopOnFALSE = TRUE)
+    for (attempt in 1:2) {
+      fs <- qs::qsave(obj, file = fts, nthreads = getOption("reproducible.nThreads", 1),
+                      preset = getOption("reproducible.qsavePreset", "high"))
+      fs1 <- file.size(fts)
+      if (!identical(fs, fs1)) {
+        if (attempt == 1) {
+          warning("Attempted to save to Cache, but save seemed to fail; trying again")
+        } else {
+          stop("Saving to Cache did not work correctly; file appears corrupted. Please retry")
+        }
+      } else {
+        break
+      }
+    }
+  } else {
+    saveRDS(obj, file = fts)
+    fs <- sum(file.size(fts))
+  }
+  fs <- sum(fs, fsOther)
+
 
   fs
 }
@@ -912,7 +883,7 @@ getDrv <- function(drv  = NULL) {
 
 saveDBFileSingle <- function(dt, cachePath, cacheId) {
   dtFile <- CacheDBFileSingle(cachePath = cachePath, cacheId = cacheId)
-  saveFileInCacheFolder(dt, dtFile, cachePath = cachePath, cacheId = cacheId)
+  saveFilesInCacheFolder(dt, dtFile, cachePath = cachePath, cacheId = cacheId)
   dtFile
 }
 
