@@ -1322,6 +1322,12 @@ makeAbsolute <- function(files, absoluteBase) {
 }
 
 makeRelative <- function(files, absoluteBase) {
+  isList <- is(files, "list")
+  filesOrig <- files
+  if (isList) {
+    nams <- names(files)
+    files <- unlist(files)
+  }
   if (length(files)) {
     areAbs <- isAbsolutePath(files)
     if (any(areAbs)) {
@@ -1329,6 +1335,10 @@ makeRelative <- function(files, absoluteBase) {
       files[areAbs] <- gsub(paste0(absoluteBase, "/*"), "", files[areAbs])
     }
   }
+  if (isList) {
+    if (length(nams) == length(files))
+      names(files) <- nams
+  }
   files
 }
 
