@@ -171,6 +171,8 @@ setMethod(
       if (!requireNamespace("terra", quietly = TRUE))
         stop("Please install terra package")
       forDig <- wrapSpatVector(object)
+    } else if (inherits(object, "SpatExtent")) {
+      forDig <- .wrap(object)
     } else {
       forDig <- .removeCacheAtts(object)
     }
@@ -403,9 +405,7 @@ basenames3 <- function(object, nParentDirs) {
   x
 }
 
-
 .CopyCacheAtts <- function(from, to) {
-
   onDiskRaster <- FALSE
   namesFrom <- names(from)
   if (!is.null(namesFrom)) { # has to have names
@@ -416,9 +416,7 @@ basenames3 <- function(object, nParentDirs) {
       if (length(from) && length(to)) {
         nams <- grep("^\\.mods$|^\\._", namesFrom, value = TRUE, invert = TRUE)
         for (nam in nams) {
-          lala <- try(.CopyCacheAtts(from[[nam]], to[[nam]]))
-          if (is(lala, 'try-error')) browser()
-          to[[nam]] <- lala
+          to[[nam]] <- try(.CopyCacheAtts(from[[nam]], to[[nam]]))
         }
       }
 
